@@ -1,9 +1,9 @@
 #' @title Check if type string is of certain type.
 #'
-#' @description
-#' \code{TRUE} iff the type string is a certain type,
-#' e.g. \code{isIntegerTypeString} checks if we have \dQuote{integer} or \dQuote{integervector},
-#' and \code{isVectorTypeString} check if we have \dQuote{*vector}.
+#' @description `TRUE` iff the type string is a certain type, e.g.
+#' `isIntegerTypeString` checks if we have \dQuote{integer} or
+#' \dQuote{integervector}, and `isVectorTypeString` check if we have
+#' \dQuote{*vector}.
 #'
 #' @template arg_typestring
 #' @template arg_include_int
@@ -16,36 +16,35 @@ NULL
 #' @export
 #' @rdname isTypeString
 isNumericTypeString = function(type, include.int = TRUE) {
-  type %in% getTypeStringsNumeric(include.int)
+  type %fin% getTypeStringsNumeric(include.int)
 }
 
 #' @export
 #' @rdname isTypeString
 isIntegerTypeString = function(type) {
-  type %in% getTypeStringsInteger()
+  type %fin% getTypeStringsInteger()
 }
 
 #' @export
 #' @rdname isTypeString
 isCharacterTypeString = function(type) {
-  type %in% getTypeStringsCharacter()
+  type %fin% getTypeStringsCharacter()
 }
 
 #' @export
 #' @rdname isTypeString
 isDiscreteTypeString = function(type, include.logical = TRUE) {
-  type %in% getTypeStringsDiscrete(include.logical)
+  type %fin% getTypeStringsDiscrete(include.logical)
 }
 
 #' @export
 #' @rdname isTypeString
 isLogicalTypeString = function(type) {
-  type %in% getTypeStringsLogical()
+  type %fin% getTypeStringsLogical()
 }
 
 #' @export
 #' @rdname isTypeString
 isVectorTypeString = function(type) {
-  grepl("vector", fixed = TRUE, type)
+  endsWith(type, "vector")
 }
-
