@@ -1,5 +1,3 @@
-context("generateRandomDesign")
-
 test_that("num/int/disc vec design", {
   ps = makeParamSet(
     makeNumericParam("x", lower = -2, upper = 1),
@@ -11,22 +9,22 @@ test_that("num/int/disc vec design", {
   expect_equal(nrow(des), 13)
   expect_equal(ncol(des), 8)
   expect_equal(colnames(des), c("x", "y1", "y2", "y3", "z1", "z2", "a1", "a2"))
-  expect_true(is.numeric(des[,1]))
-  expect_true(is.integer(des[,2]))
-  expect_true(is.integer(des[,3]))
-  expect_true(is.integer(des[,4]))
-  expect_true(is.factor(des[,5]))
-  expect_true(is.factor(des[,6]))
-  expect_true(is.logical(des[,7]))
-  expect_true(is.logical(des[,8]))
-  expect_true(des[,1] >= -2 && des[,1] <= 1)
-  expect_true(des[,2] >= 10 && des[,2] <= 20)
-  expect_true(des[,3] >= 10 && des[,3] <= 20)
-  expect_true(des[,4] >= 10 && des[,4] <= 20)
-  expect_true(all(des[,5] %in% c("a", "b")))
-  expect_true(all(des[,6] %in% c("a", "b")))
-  expect_equal(levels(des[,5]), c("a", "b"))
-  expect_equal(levels(des[,6]), c("a", "b"))
+  expect_true(is.numeric(des[, 1]))
+  expect_true(is.integer(des[, 2]))
+  expect_true(is.integer(des[, 3]))
+  expect_true(is.integer(des[, 4]))
+  expect_true(is.factor(des[, 5]))
+  expect_true(is.factor(des[, 6]))
+  expect_true(is.logical(des[, 7]))
+  expect_true(is.logical(des[, 8]))
+  expect_true(all(des[, 1] >= -2) && all(des[, 1] <= 1))
+  expect_true(all(des[, 2] >= 10) && all(des[, 2] <= 20))
+  expect_true(all(des[, 3] >= 10) && all(des[, 3] <= 20))
+  expect_true(all(des[, 4] >= 10) && all(des[, 4] <= 20))
+  expect_true(all(des[, 5] %in% c("a", "b")))
+  expect_true(all(des[, 6] %in% c("a", "b")))
+  expect_equal(levels(des[, 5]), c("a", "b"))
+  expect_equal(levels(des[, 6]), c("a", "b"))
 })
 
 test_that("requires works", {
@@ -54,5 +52,5 @@ test_that("we dont drop levels in factors", {
     makeDiscreteParam("x", values = letters[5:1])
   )
   des = generateRandomDesign(1, ps)
-  expect_true(is.factor(des$x) && levels(des$x) == letters[5:1])
+  expect_true(is.factor(des$x) && all(levels(des$x) == letters[5:1]))
 })
